@@ -1,18 +1,4 @@
 """
-macrodemos: A Python module to teach macroeconomics and macroeconometrics
-
-Randall Romero Aguilar
-2016-2020
-"""
-#import .constants
-#import .common_components
-from .captura import read_IFS
-from .demo_ARMA import ARMA_demo
-from .demo_Solow import Solow_demo
-from .demo_Markov import Markov_demo
-from .demo_filters import filters_demo
-
-msg = """
 macrodemos : A Python module to teach macroeconomics and macroeconometrics
 
 This package contains Dash apps to teach and learn about macroeconomics and macroeconometrics.
@@ -21,9 +7,17 @@ So far, the available demos are:
 
     ARMA_demo():  to study AutoRegressive Moving Average processes.
     filters_demo(): to compare several filtering methods.
-    Markov_demo(): to study Markov chains. 
+    Markov_demo(): to study Markov chains.
     Solow_demo():  to study the Solow growth model.
-    
-Randall Romero Aguilar, 2016-2020   
+
+Randall Romero Aguilar, 2016-2021
 """
-print(msg)
\ No newline at end of file
+
+#import .constants
+#import .common_components
+from .captura import read_IFS
+from .demo_ARMA import ARMA_demo
+from .demo_Solow import Solow_demo
+from .demo_Markov import Markov_demo
+from .demo_filters import filters_demo
+
